@@ -320,7 +320,20 @@ proc fasta2frag::fragASeq {nonamedata name fout quals qout mpout mbout} {
 	puts $bla
     }
 
-    for { } {$from < $datalen} { incr from $opts(-i); incr to $opts(-i); incr seqid} {
+    proc random {{range 100}} {
+	return [expr {25+int(rand()*$range)}]
+    }
+
+    proc getFragLen {from } {
+	variable opts
+	#return [expr {$from+[random $opts(-l)]*2}]
+	return [expr {$from+$opts(-l)}]
+    }
+
+    #for { } {$from < $datalen} { incr from $opts(-i); incr to $opts(-i); incr seqid} 
+    for { } {$from < $datalen} { incr from $opts(-i); incr seqid} {
+	#set to [expr {$from+$opts(-l)}]
+	set to [getFragLen $from]
 	if {$lastflag == 0} {
 	    #puts "$from $to"
 	    
@@ -419,8 +432,8 @@ proc fasta2frag::fragASeq {nonamedata name fout quals qout mpout mbout} {
 			set dnaseq [string range $data $from [expr {$to-1}]]
 			set qualseq [getqualfromto $dnaseq $quals $from $to]
 
-			puts "quals: $quals"
-			puts "dnaqualseq: $qualseq"
+			#puts "quals: $quals"
+			#puts "dnaqualseq: $qualseq"
 
 			set descline "[expr {$opts(-insert_size)-$opts(-insert_stdev)}] $opts(-insert_size) [expr {$opts(-insert_size)+$opts(-insert_stdev)}] 1 [string length $dnaseq]"
 			if {$rev1} {
